from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_Cypress = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'CY7C68013A-56LTX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY7C68013A-56LTX'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-56-1EP_8x8mm_P0.5mm_EP4.5x5.2mm_ThermalVias_TopTented'], 'footprint':'Package_DFN_QFN:QFN-56-1EP_8x8mm_P0.5mm_EP4.5x5.2mm_ThermalVias_TopTented', 'keywords':'FX2LP 8-bit USB MCU', 'description':'', 'datasheet':'http://www.cypress.com/file/138911/download', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCY7C68013A-56LTX\n\nFX2LP 8-bit USB MCU', 'pins':[
            Pin(num='1',name='RDY0/SLRD',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='IFCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RESERVED',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='PB0/FD0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1/FD1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RDY1/SLWR',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PB2/FD2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB3/FD3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB4/FD4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB5/FD5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB6/FD6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB7/FD7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='CTL0/FLAGA',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='CTL1/FLAGB',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='CTL2/FLAGC',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='PA0/~{INT0}',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA1/~{INT1}',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2/SLOE',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA3/WU2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA4/FIOADDR0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA5/FIOADDR1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA6/PKTEND',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='PA7/FLAGD/~{SLCS}',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='WAKEUP',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PD0/FD8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD1/FD9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD2/FD10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD3/FD11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD4/FD12',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='PD5/FD13',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD6/FD14',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD7/FD15',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='55',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='EP',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='D-',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY7C68013A-56PVX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY7C68013A-56PVX'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-56_7.5x18.5mm_P0.635mm'], 'footprint':'Package_SO:SSOP-56_7.5x18.5mm_P0.635mm', 'keywords':'FX2LP 8-bit USB MCU', 'description':'', 'datasheet':'http://www.cypress.com/file/138911/download', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCY7C68013A-56PVX\n\nFX2LP 8-bit USB MCU', 'pins':[
            Pin(num='1',name='PD5/FD13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='PD6/FD14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='IFCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RESERVED',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='PB0/FD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB1/FD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB2/FD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB3/FD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB4/FD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD7/FD15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB5/FD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB6/FD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB7/FD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='CTL0/FLAGA',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='CTL1/FLAGB',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='CTL2/FLAGC',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='PA0/~{INT0}',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1/~{INT1}',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2/SLOE',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA3/WU2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA4/FIOADDR0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA5/FIOADDR1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA6/PKTEND',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA7/FLAGD/~{SLCS}',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='50',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='WAKEUP',func=pin_types.INPUT,unit=1),
            Pin(num='52',name='PD0/FD8',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD1/FD9',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2/FD10',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD3/FD11',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD4/FD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='RDY0/SLRD',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='RDY1/SLWR',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY8C4245AXI-M445', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY8C4245AXI-M445'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'Cypress Microcontroller Arm CapSense LCD', 'description':'', 'datasheet':'https://www.cypress.com/file/139956/download', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCY8C4245AXI-M445\n\nCypress Microcontroller Arm CapSense LCD', 'pins':[
            Pin(num='1',name='P1.7/VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='P6.0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P6.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P6.2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P6.4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P6.5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VSSIO',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='P7.0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P7.1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='XRES',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P5.2',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P5.3',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY8C4245AZI-M445', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY8C4245AZI-M445'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'keywords':'Cypress Microcontroller Arm CapSense LCD', 'description':'', 'datasheet':'https://www.cypress.com/file/139956/download', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCY8C4245AZI-M445\n\nCypress Microcontroller Arm CapSense LCD', 'pins':[
            Pin(num='1',name='P1.7/VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='P6.0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P6.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P6.2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P6.4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P6.5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VSSIO',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='P7.0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P7.1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='XRES',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P5.2',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P5.3',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY8C4xx7LQI-4xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY8C4xx7LQI-4xx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'keywords':'CYPRESS PSOC BLE CY8 CY8C4 ARM CORTEX M0 BLUETOOTH QFN', 'description':'', 'datasheet':'http://www.cypress.com/file/137466/download', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCY8C4xx7LQI-4xx\n\nCYPRESS PSOC BLE CY8 CY8C4 ARM CORTEX M0 BLUETOOTH QFN', 'pins':[
            Pin(num='1',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GANT1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='ANT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='GANT2',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL24I',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='XTAL24O',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL32O/P6.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL32I/P6.1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='XRES',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='57',name='GND_EP',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSSD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CYBL10563-68FNXIT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CYBL10563-68FNXIT'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'CYPRESS PROC BLE CY8BL ARM CORTEX M0 BLUETOOTH WLCSP', 'description':'', 'datasheet':'http://www.cypress.com/documentation/datasheets/cybl10x6x-family-datasheet-programmable-radio-chip-bluetooth-low-energy', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCYBL10563-68FNXIT\n\nCYPRESS PROC BLE CY8BL ARM CORTEX M0 BLUETOOTH WLCSP', 'pins':[
            Pin(num='11',name='GANT1',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='GND_EP',func=pin_types.PWRIN,unit=1),
            Pin(num='A1',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='A8',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSSA',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='XTAL32I/P6.1',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='XTAL32O/P6.0',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='XRES',func=pin_types.INPUT,unit=1),
            Pin(num='C8',name='P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSSR',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VSSR',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G3',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='G5',name='VSSR',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSSR',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='GANT2',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSSR',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='XTAL24O',func=pin_types.OUTPUT,unit=1),
            Pin(num='H4',name='XTAL24I',func=pin_types.INPUT,unit=1),
            Pin(num='H5',name='VSSR',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSSR',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='ANT',func=pin_types.OUTPUT,unit=1),
            Pin(num='J1',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J7',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CYBL10x6x-56LQxx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CYBL10x6x-56LQxx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'keywords':'CYPRESS PROC BLE CY8BL ARM CORTEX M0 BLUETOOTH QFN', 'description':'', 'datasheet':'http://www.cypress.com/documentation/datasheets/cybl10x6x-family-datasheet-programmable-radio-chip-bluetooth-low-energy', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCYBL10x6x-56LQxx\n\nCYPRESS PROC BLE CY8BL ARM CORTEX M0 BLUETOOTH QFN', 'pins':[
            Pin(num='1',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GANT1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='ANT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='GANT2',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL24I',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='XTAL24O',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL32O/P6.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL32I/P6.1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='XRES',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='57',name='GND_EP',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSSD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY7C68014A-56LTX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY7C68014A-56LTX'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-56-1EP_8x8mm_P0.5mm_EP4.5x5.2mm_ThermalVias_TopTented', 'Package_DFN_QFN:QFN-56-1EP_8x8mm_P0.5mm_EP4.5x5.2mm_ThermalVias_TopTented'], 'footprint':'Package_DFN_QFN:QFN-56-1EP_8x8mm_P0.5mm_EP4.5x5.2mm_ThermalVias_TopTented', 'keywords':'FX2LP 8-bit USB MCU', 'description':'', 'datasheet':'http://www.cypress.com/file/138911/download', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCY7C68014A-56LTX\n\nFX2LP 8-bit USB MCU', 'pins':[
            Pin(num='1',name='RDY0/SLRD',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='IFCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RESERVED',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='PB0/FD0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1/FD1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RDY1/SLWR',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PB2/FD2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB3/FD3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB4/FD4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB5/FD5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB6/FD6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB7/FD7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='CTL0/FLAGA',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='CTL1/FLAGB',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='CTL2/FLAGC',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='PA0/~{INT0}',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA1/~{INT1}',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2/SLOE',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA3/WU2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA4/FIOADDR0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA5/FIOADDR1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA6/PKTEND',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='PA7/FLAGD/~{SLCS}',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='WAKEUP',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PD0/FD8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD1/FD9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD2/FD10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD3/FD11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD4/FD12',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='PD5/FD13',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD6/FD14',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD7/FD15',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='55',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='EP',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='D-',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY7C68014A-56PVX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY7C68014A-56PVX'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-56_7.5x18.5mm_P0.635mm', 'Package_SO:SSOP-56_7.5x18.5mm_P0.635mm'], 'footprint':'Package_SO:SSOP-56_7.5x18.5mm_P0.635mm', 'keywords':'FX2LP 8-bit USB MCU', 'description':'', 'datasheet':'http://www.cypress.com/file/138911/download', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCY7C68014A-56PVX\n\nFX2LP 8-bit USB MCU', 'pins':[
            Pin(num='1',name='PD5/FD13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='PD6/FD14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='IFCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RESERVED',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='PB0/FD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB1/FD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB2/FD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB3/FD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB4/FD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD7/FD15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB5/FD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB6/FD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB7/FD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='CTL0/FLAGA',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='CTL1/FLAGB',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='CTL2/FLAGC',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='PA0/~{INT0}',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1/~{INT1}',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2/SLOE',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA3/WU2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA4/FIOADDR0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA5/FIOADDR1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA6/PKTEND',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA7/FLAGD/~{SLCS}',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='50',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='WAKEUP',func=pin_types.INPUT,unit=1),
            Pin(num='52',name='PD0/FD8',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD1/FD9',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2/FD10',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD3/FD11',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD4/FD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='RDY0/SLRD',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='RDY1/SLWR',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY8C4127LQI-BL453', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY8C4127LQI-BL453'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'keywords':'CYPRESS PSOC BLE CY8 CY8C4 ARM CORTEX M0 BLUETOOTH QFN', 'description':'', 'datasheet':'http://www.cypress.com/file/137466/download', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCY8C4127LQI-BL453\n\nCYPRESS PSOC BLE CY8 CY8C4 ARM CORTEX M0 BLUETOOTH QFN', 'pins':[
            Pin(num='1',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GANT1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='ANT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='GANT2',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL24I',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='XTAL24O',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL32O/P6.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL32I/P6.1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='XRES',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='57',name='GND_EP',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSSD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY8C4127LQI-BL473', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY8C4127LQI-BL473'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'keywords':'CYPRESS PSOC BLE CY8 CY8C4 ARM CORTEX M0 BLUETOOTH QFN', 'description':'', 'datasheet':'http://www.cypress.com/file/137466/download', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCY8C4127LQI-BL473\n\nCYPRESS PSOC BLE CY8 CY8C4 ARM CORTEX M0 BLUETOOTH QFN', 'pins':[
            Pin(num='1',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GANT1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='ANT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='GANT2',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL24I',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='XTAL24O',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL32O/P6.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL32I/P6.1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='XRES',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='57',name='GND_EP',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSSD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY8C4127LQI-BL483', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY8C4127LQI-BL483'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'keywords':'CYPRESS PSOC BLE CY8 CY8C4 ARM CORTEX M0 BLUETOOTH QFN', 'description':'', 'datasheet':'http://www.cypress.com/file/137466/download', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCY8C4127LQI-BL483\n\nCYPRESS PSOC BLE CY8 CY8C4 ARM CORTEX M0 BLUETOOTH QFN', 'pins':[
            Pin(num='1',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GANT1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='ANT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='GANT2',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL24I',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='XTAL24O',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL32O/P6.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL32I/P6.1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='XRES',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='57',name='GND_EP',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSSD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY8C4127LQI-BL493', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY8C4127LQI-BL493'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'keywords':'CYPRESS PSOC BLE CY8 CY8C4 ARM CORTEX M0 BLUETOOTH QFN', 'description':'', 'datasheet':'http://www.cypress.com/file/137466/download', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCY8C4127LQI-BL493\n\nCYPRESS PSOC BLE CY8 CY8C4 ARM CORTEX M0 BLUETOOTH QFN', 'pins':[
            Pin(num='1',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GANT1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='ANT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='GANT2',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL24I',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='XTAL24O',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL32O/P6.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL32I/P6.1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='XRES',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='57',name='GND_EP',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSSD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY8C4246AXI-M445', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY8C4246AXI-M445'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'Cypress Microcontroller Arm CapSense LCD', 'description':'', 'datasheet':'https://www.cypress.com/file/139956/download', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCY8C4246AXI-M445\n\nCypress Microcontroller Arm CapSense LCD', 'pins':[
            Pin(num='1',name='P1.7/VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='P6.0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P6.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P6.2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P6.4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P6.5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VSSIO',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='P7.0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P7.1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='XRES',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P5.2',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P5.3',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY8C4246AZI-M445', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY8C4246AZI-M445'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_10x10mm_P0.5mm', 'Package_QFP:TQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'keywords':'Cypress Microcontroller Arm CapSense LCD', 'description':'', 'datasheet':'https://www.cypress.com/file/139956/download', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCY8C4246AZI-M445\n\nCypress Microcontroller Arm CapSense LCD', 'pins':[
            Pin(num='1',name='P1.7/VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='P6.0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P6.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P6.2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P6.4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P6.5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VSSIO',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='P7.0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P7.1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='XRES',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P5.2',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P5.3',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY8C4246AZI-M475', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY8C4246AZI-M475'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_10x10mm_P0.5mm', 'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'Package_QFP:TQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'keywords':'Cypress Microcontroller Arm IDAC', 'description':'', 'datasheet':'https://www.cypress.com/file/139956/download', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCY8C4246AZI-M475\n\nCypress Microcontroller Arm IDAC', 'pins':[
            Pin(num='1',name='P1.7/VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='P6.0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P6.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P6.2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P6.4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P6.5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VSSIO',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='P7.0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P7.1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='XRES',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P5.2',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P5.3',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY8C4247AXI-M485', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY8C4247AXI-M485'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'Cypress Microcontroller Arm CapSense IDAC LCD CAN', 'description':'', 'datasheet':'https://www.cypress.com/file/139956/download', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCY8C4247AXI-M485\n\nCypress Microcontroller Arm CapSense IDAC LCD CAN', 'pins':[
            Pin(num='1',name='P1.7/VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='P6.0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P6.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P6.2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P6.4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P6.5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VSSIO',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='P7.0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P7.1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='XRES',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P5.2',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P5.3',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY8C4247AZI-M475', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY8C4247AZI-M475'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_10x10mm_P0.5mm', 'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'Package_QFP:TQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'keywords':'Cypress Microcontroller Arm IDAC', 'description':'', 'datasheet':'https://www.cypress.com/file/139956/download', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCY8C4247AZI-M475\n\nCypress Microcontroller Arm IDAC', 'pins':[
            Pin(num='1',name='P1.7/VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='P6.0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P6.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P6.2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P6.4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P6.5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VSSIO',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='P7.0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P7.1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='XRES',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P5.2',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P5.3',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY8C4247AZI-M485', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY8C4247AZI-M485'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_10x10mm_P0.5mm', 'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'Package_QFP:TQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'keywords':'Cypress Microcontroller Arm CapSense IDAC LCD CAN', 'description':'', 'datasheet':'https://www.cypress.com/file/139956/download', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCY8C4247AZI-M485\n\nCypress Microcontroller Arm CapSense IDAC LCD CAN', 'pins':[
            Pin(num='1',name='P1.7/VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='P6.0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P6.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P6.2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P6.4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P6.5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VSSIO',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='P7.0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P7.1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='XRES',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P5.2',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P5.3',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY8C4247LQI-BL453', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY8C4247LQI-BL453'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'keywords':'CYPRESS PSOC BLE CY8 CY8C4 ARM CORTEX M0 BLUETOOTH QFN', 'description':'', 'datasheet':'http://www.cypress.com/file/137466/download', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCY8C4247LQI-BL453\n\nCYPRESS PSOC BLE CY8 CY8C4 ARM CORTEX M0 BLUETOOTH QFN', 'pins':[
            Pin(num='1',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GANT1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='ANT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='GANT2',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL24I',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='XTAL24O',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL32O/P6.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL32I/P6.1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='XRES',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='57',name='GND_EP',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSSD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY8C4247LQI-BL463', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY8C4247LQI-BL463'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'keywords':'CYPRESS PSOC BLE CY8 CY8C4 ARM CORTEX M0 BLUETOOTH QFN', 'description':'', 'datasheet':'http://www.cypress.com/file/137466/download', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCY8C4247LQI-BL463\n\nCYPRESS PSOC BLE CY8 CY8C4 ARM CORTEX M0 BLUETOOTH QFN', 'pins':[
            Pin(num='1',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GANT1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='ANT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='GANT2',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL24I',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='XTAL24O',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL32O/P6.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL32I/P6.1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='XRES',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='57',name='GND_EP',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSSD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY8C4247LQI-BL473', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY8C4247LQI-BL473'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'keywords':'CYPRESS PSOC BLE CY8 CY8C4 ARM CORTEX M0 BLUETOOTH QFN', 'description':'', 'datasheet':'http://www.cypress.com/file/137466/download', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCY8C4247LQI-BL473\n\nCYPRESS PSOC BLE CY8 CY8C4 ARM CORTEX M0 BLUETOOTH QFN', 'pins':[
            Pin(num='1',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GANT1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='ANT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='GANT2',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL24I',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='XTAL24O',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL32O/P6.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL32I/P6.1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='XRES',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='57',name='GND_EP',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSSD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY8C4247LQI-BL483', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY8C4247LQI-BL483'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'keywords':'CYPRESS PSOC BLE CY8 CY8C4 ARM CORTEX M0 BLUETOOTH QFN', 'description':'', 'datasheet':'http://www.cypress.com/file/137466/download', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCY8C4247LQI-BL483\n\nCYPRESS PSOC BLE CY8 CY8C4 ARM CORTEX M0 BLUETOOTH QFN', 'pins':[
            Pin(num='1',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GANT1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='ANT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='GANT2',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL24I',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='XTAL24O',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL32O/P6.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL32I/P6.1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='XRES',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='57',name='GND_EP',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSSD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY8C4247LQI-BL493', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY8C4247LQI-BL493'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'keywords':'CYPRESS PSOC BLE CY8 CY8C4 ARM CORTEX M0 BLUETOOTH QFN', 'description':'', 'datasheet':'http://www.cypress.com/file/137466/download', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCY8C4247LQI-BL493\n\nCYPRESS PSOC BLE CY8 CY8C4 ARM CORTEX M0 BLUETOOTH QFN', 'pins':[
            Pin(num='1',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GANT1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='ANT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='GANT2',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL24I',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='XTAL24O',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL32O/P6.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL32I/P6.1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='XRES',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='57',name='GND_EP',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSSD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY8C4247LQQ-BL483', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY8C4247LQQ-BL483'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'keywords':'CYPRESS PSOC BLE CY8 CY8C4 ARM CORTEX M0 BLUETOOTH QFN', 'description':'', 'datasheet':'http://www.cypress.com/file/137466/download', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCY8C4247LQQ-BL483\n\nCYPRESS PSOC BLE CY8 CY8C4 ARM CORTEX M0 BLUETOOTH QFN', 'pins':[
            Pin(num='1',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GANT1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='ANT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='GANT2',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL24I',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='XTAL24O',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL32O/P6.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL32I/P6.1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='XRES',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='57',name='GND_EP',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSSD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CYBL10161-56LQXI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CYBL10161-56LQXI'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'keywords':'CYPRESS PROC BLE CY8BL ARM CORTEX M0 BLUETOOTH QFN', 'description':'', 'datasheet':'http://www.cypress.com/documentation/datasheets/cybl10x6x-family-datasheet-programmable-radio-chip-bluetooth-low-energy', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCYBL10161-56LQXI\n\nCYPRESS PROC BLE CY8BL ARM CORTEX M0 BLUETOOTH QFN', 'pins':[
            Pin(num='1',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GANT1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='ANT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='GANT2',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL24I',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='XTAL24O',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL32O/P6.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL32I/P6.1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='XRES',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='57',name='GND_EP',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSSD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CYBL10162-56LQXI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CYBL10162-56LQXI'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'keywords':'CYPRESS PROC BLE CY8BL ARM CORTEX M0 BLUETOOTH QFN', 'description':'', 'datasheet':'http://www.cypress.com/documentation/datasheets/cybl10x6x-family-datasheet-programmable-radio-chip-bluetooth-low-energy', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCYBL10162-56LQXI\n\nCYPRESS PROC BLE CY8BL ARM CORTEX M0 BLUETOOTH QFN', 'pins':[
            Pin(num='1',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GANT1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='ANT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='GANT2',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL24I',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='XTAL24O',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL32O/P6.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL32I/P6.1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='XRES',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='57',name='GND_EP',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSSD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CYBL10163-56LQXI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CYBL10163-56LQXI'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'keywords':'CYPRESS PROC BLE CY8BL ARM CORTEX M0 BLUETOOTH QFN', 'description':'', 'datasheet':'http://www.cypress.com/documentation/datasheets/cybl10x6x-family-datasheet-programmable-radio-chip-bluetooth-low-energy', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCYBL10163-56LQXI\n\nCYPRESS PROC BLE CY8BL ARM CORTEX M0 BLUETOOTH QFN', 'pins':[
            Pin(num='1',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GANT1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='ANT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='GANT2',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL24I',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='XTAL24O',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL32O/P6.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL32I/P6.1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='XRES',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='57',name='GND_EP',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSSD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CYBL10461-56LQXI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CYBL10461-56LQXI'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'keywords':'CYPRESS PROC BLE CY8BL ARM CORTEX M0 BLUETOOTH QFN', 'description':'', 'datasheet':'http://www.cypress.com/documentation/datasheets/cybl10x6x-family-datasheet-programmable-radio-chip-bluetooth-low-energy', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCYBL10461-56LQXI\n\nCYPRESS PROC BLE CY8BL ARM CORTEX M0 BLUETOOTH QFN', 'pins':[
            Pin(num='1',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GANT1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='ANT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='GANT2',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL24I',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='XTAL24O',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL32O/P6.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL32I/P6.1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='XRES',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='57',name='GND_EP',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSSD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CYBL10462-56LQXI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CYBL10462-56LQXI'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'keywords':'CYPRESS PROC BLE CY8BL ARM CORTEX M0 BLUETOOTH QFN', 'description':'', 'datasheet':'http://www.cypress.com/documentation/datasheets/cybl10x6x-family-datasheet-programmable-radio-chip-bluetooth-low-energy', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCYBL10462-56LQXI\n\nCYPRESS PROC BLE CY8BL ARM CORTEX M0 BLUETOOTH QFN', 'pins':[
            Pin(num='1',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GANT1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='ANT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='GANT2',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL24I',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='XTAL24O',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL32O/P6.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL32I/P6.1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='XRES',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='57',name='GND_EP',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSSD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CYBL10463-56LQXI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CYBL10463-56LQXI'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'keywords':'CYPRESS PROC BLE CY8BL ARM CORTEX M0 BLUETOOTH QFN', 'description':'', 'datasheet':'http://www.cypress.com/documentation/datasheets/cybl10x6x-family-datasheet-programmable-radio-chip-bluetooth-low-energy', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCYBL10463-56LQXI\n\nCYPRESS PROC BLE CY8BL ARM CORTEX M0 BLUETOOTH QFN', 'pins':[
            Pin(num='1',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GANT1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='ANT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='GANT2',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL24I',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='XTAL24O',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL32O/P6.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL32I/P6.1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='XRES',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='57',name='GND_EP',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSSD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CYBL10561-56LQXI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CYBL10561-56LQXI'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'keywords':'CYPRESS PROC BLE CY8BL ARM CORTEX M0 BLUETOOTH QFN', 'description':'', 'datasheet':'http://www.cypress.com/documentation/datasheets/cybl10x6x-family-datasheet-programmable-radio-chip-bluetooth-low-energy', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCYBL10561-56LQXI\n\nCYPRESS PROC BLE CY8BL ARM CORTEX M0 BLUETOOTH QFN', 'pins':[
            Pin(num='1',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GANT1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='ANT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='GANT2',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL24I',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='XTAL24O',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL32O/P6.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL32I/P6.1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='XRES',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='57',name='GND_EP',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSSD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CYBL10562-56LQXI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CYBL10562-56LQXI'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'keywords':'CYPRESS PROC BLE CY8BL ARM CORTEX M0 BLUETOOTH QFN', 'description':'', 'datasheet':'http://www.cypress.com/documentation/datasheets/cybl10x6x-family-datasheet-programmable-radio-chip-bluetooth-low-energy', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCYBL10562-56LQXI\n\nCYPRESS PROC BLE CY8BL ARM CORTEX M0 BLUETOOTH QFN', 'pins':[
            Pin(num='1',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GANT1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='ANT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='GANT2',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL24I',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='XTAL24O',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL32O/P6.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL32I/P6.1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='XRES',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='57',name='GND_EP',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSSD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CYBL10563-56LQXI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CYBL10563-56LQXI'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'keywords':'CYPRESS PROC BLE CY8BL ARM CORTEX M0 BLUETOOTH QFN', 'description':'', 'datasheet':'http://www.cypress.com/documentation/datasheets/cybl10x6x-family-datasheet-programmable-radio-chip-bluetooth-low-energy', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCYBL10563-56LQXI\n\nCYPRESS PROC BLE CY8BL ARM CORTEX M0 BLUETOOTH QFN', 'pins':[
            Pin(num='1',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GANT1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='ANT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='GANT2',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL24I',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='XTAL24O',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL32O/P6.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL32I/P6.1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='XRES',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='57',name='GND_EP',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSSD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CYBL10563-56LQXQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CYBL10563-56LQXQ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-56-1EP_7x7mm_P0.4mm_EP5.6x5.6mm', 'keywords':'CYPRESS PROC BLE CY8BL ARM CORTEX M0 BLUETOOTH QFN', 'description':'', 'datasheet':'http://www.cypress.com/documentation/datasheets/cybl10x6x-family-datasheet-programmable-radio-chip-bluetooth-low-energy', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCYBL10563-56LQXQ\n\nCYPRESS PROC BLE CY8BL ARM CORTEX M0 BLUETOOTH QFN', 'pins':[
            Pin(num='1',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GANT1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='ANT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='GANT2',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL24I',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='XTAL24O',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL32O/P6.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL32I/P6.1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='XRES',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='57',name='GND_EP',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSSD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CYBL10563-68FLXIT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CYBL10563-68FLXIT'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'CYPRESS PROC BLE CY8BL ARM CORTEX M0 BLUETOOTH WLCSP', 'description':'', 'datasheet':'http://www.cypress.com/documentation/datasheets/cybl10x6x-family-datasheet-programmable-radio-chip-bluetooth-low-energy', 'search_text':'/usr/share/kicad/symbols/MCU_Cypress.kicad_sym\nCYBL10563-68FLXIT\n\nCYPRESS PROC BLE CY8BL ARM CORTEX M0 BLUETOOTH WLCSP', 'pins':[
            Pin(num='11',name='GANT1',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='GND_EP',func=pin_types.PWRIN,unit=1),
            Pin(num='A1',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='A8',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSSA',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='XTAL32I/P6.1',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='XTAL32O/P6.0',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='XRES',func=pin_types.INPUT,unit=1),
            Pin(num='C8',name='P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSSR',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VSSR',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G3',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='G5',name='VSSR',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSSR',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='GANT2',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSSR',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='XTAL24O',func=pin_types.OUTPUT,unit=1),
            Pin(num='H4',name='XTAL24I',func=pin_types.INPUT,unit=1),
            Pin(num='H5',name='VSSR',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSSR',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='ANT',func=pin_types.OUTPUT,unit=1),
            Pin(num='J1',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J7',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] })])